@@ -13,7 +13,7 @@ from . import filter
 
 
 DISCRETE_PH_JUMP_THRESH = 0.2
-DISCRETE_PH_JUMP_THRESH = 30.0
+DISCRETE_ORP_JUMP_THRESH = 30.0
 # Compensate for temperature diff between readings and calibration.
 PH_TEMP_C = -0.05694  # pH/(V*T). V is in volts, and T is in °C
 
